from django.http import request
from django.shortcuts import render, HttpResponse, redirect
from django.contrib.auth.models import User, auth
from django.contrib import messages
from django.core.mail import send_mail
from django.contrib.auth import authenticate, login, logout
from django_email_verification import sendConfirm
from django.contrib.auth.decorators import login_required
from django.views.decorators.cache import cache_control


import re


@cache_control(no_cache=True, must_revalidate=True, no_store=True)
def loginview(request):
    """View for Login."""
    if request.user.is_authenticated:
        email = str(request.user.email)
        if(userTypeCheck(email) == "IITian"):
            
            return redirect("/iitiandashboard")

        
        return redirect("/normaldashboard")

    if request.method == 'POST':

        username = request.POST['username']
        password = request.POST['password']

        user = auth.authenticate(username=username, password=password)

        if user is not None:
            login(request, user)
            email = User.objects.get(username=str(username)).email
            
            if(userTypeCheck(email) == "IITian"):
                
                return redirect("/iitiandashboard")

            
            return redirect("/normaldashboard")

        else:
            messages.info(request, 'invalid credentials')
            return redirect('login')
    else:
        return render(request, 'login.html')


@cache_control(no_cache=True, must_revalidate=True, no_store=True)
def registerNormal(request):
    """View for Registeration of Normal User."""
    if request.user.is_authenticated:
        email = str(request.user.email)
        if(userTypeCheck(email) == "IITian"):
            
            return redirect("/iitiandashboard")
        
        return redirect("/normaldashboard")

    if request.method == 'POST':
        
        first_name = request.POST['first_name']
        last_name = request.POST['last_name']
        username = request.POST['username']
        password1 = request.POST['password1']
        password2 = request.POST['password2']
        email = request.POST['email']

        if password1 == password2:
            if User.objects.filter(username=username).exists():
                messages.info(request, 'Username already exists')
                return redirect('/registernormal')
            elif User.objects.filter(email=email).exists():
                messages.info(request, 'email already exists')
                return redirect('/registernormal')
            else:
                user = User.objects.create_user(username=username,
                                                password=password1,
                                                email=email,
                                                first_name=first_name,
                                                last_name=last_name)
                user.save()
                
             
                messages.info(
                    request, 'Your account has been created, Please confirm your email address to complete the registration')
                
                sendConfirm(user)
                
                return redirect('login')
        else:
            
            messages.info(request, 'password not matching')
            return redirect('/registernormal')

        return redirect('/registernormal')
    else:
        return render(request, 'registernormal.html')

@cache_control(no_cache=True, must_revalidate=True, no_store=True)
def registerIITian(request):
    """View for Registeration of IITian User."""
    if request.user.is_authenticated:
        email = str(request.user.email)
        if(userTypeCheck(email) == "IITian"):
            
            return redirect("/iitiandashboard")
        
        return redirect("/normaldashboard")

    if request.method == 'POST':
        first_name = request.POST['first_name']
        last_name = request.POST['last_name']
        username = request.POST['username']
        password1 = request.POST['password1']
        password2 = request.POST['password2']
        email = request.POST['email']

        if password1 == password2:
            if User.objects.filter(username=username).exists():
                messages.info(request, 'Username already exists')
                return redirect('/registeriitian')
            elif User.objects.filter(email=email).exists():
                messages.info(request, 'email already exists')
                return redirect('/registeriitian')
            else:
                user = User.objects.create_user(username=username,
                                                password=password1,
                                                email=email,
                                                first_name=first_name,
                                                last_name=last_name)
                user.save()
                
                messages.info(
                    request, 'Your account has been created, Please confirm your email address to complete the registration')
                
                
                sendConfirm(user)
                return redirect('login')
        else:
            
            messages.info(request, 'password not matching')
            return redirect('/registeriitian')

        return redirect('/registeriitian')
    else:
        return render(request, 'registeriitian.html')


@cache_control(no_cache=True, must_revalidate=True, no_store=True)
@login_required(login_url='/login')
def logoutview(request):
    """View for Logout User."""
    logout(request)
    messages.info(request, 'You are Logged Out.')
    return redirect("/login")



def userTypeCheck(email):
    """Function for checking the Type of User, on the basis of registered email Id."""
    normal = "^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*$"
    IITian = "^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@iit[a-z]+.ac.in$"
    if(re.search(IITian, email)):
        return "IITian"
    elif(re.search(normal, email)):
        return "normal"
    else:
        return "invalid"
